@@ -10,7 +10,7 @@ use Rose::DateTime::Parser;
 use Rose::HTML::Form::Field::Text;
 our @ISA = qw(Rose::HTML::Form::Field::Text);
 
-our $VERSION = '0.541';
+our $VERSION = '0.549';
 
 use Rose::Object::MakeMethods::Generic
 (
@@ -42,7 +42,9 @@ sub inflate_value
 {
   my($self, $date) = @_;
   return undef  unless(ref $date || (defined $date && length $date));
-  return $self->date_parser->parse_datetime($date);
+  my $dt;
+  eval { $dt = $self->date_parser->parse_datetime($date) };
+  return $dt;
 }
 
 sub init_output_format { '%Y-%m-%d %I:%M:%S %p' }
@@ -58,11 +60,15 @@ sub validate
 {
   my($self) = shift;
 
-  my $ok = $self->SUPER::validate(@_);
-  return $ok  unless($ok);
+  no warnings 'uninitialized';
+  if($self->input_value !~ /\S/)
+  {
+    my $ok = $self->SUPER::validate(@_);
+    return $ok  unless($ok);
+  }
 
   my $date = $self->internal_value;
-  return 1  if(ref $date eq 'DateTime');
+  return 1  if(UNIVERSAL::isa($date, 'DateTime'));
 
   if($self->has_partial_value)
   {
@@ -79,15 +85,16 @@ sub validate
   unless(defined $date)
   {
     # XXX: Parser errors ar English-only right now...
-    if($self->locale eq 'en')
-    {
-      $self->add_error($self->date_parser->error)
-        if($self->date_parser->can('error'));
-    }
-    else
-    {
+    # XXX: ...but it produces some horribly ugly errors.
+    #if($self->locale eq 'en')
+    #{
+    #  $self->add_error($self->date_parser->error)
+    #    if($self->date_parser->can('error'));
+    #}
+    #else
+    #{
       $self->add_error_id(DATE_INVALID);
-    }
+    #}
 
     return 0;
   }
@@ -116,6 +123,10 @@ DATE_INVALID = "Ungültiges Datum."
 
 DATE_INVALID = "Date invalide."
 
+[% LOCALE bg %]
+
+DATE_INVALID = "Невалидна дата."
+
 __END__
 
 =head1 NAME
@@ -210,7 +221,7 @@ A compound field that includes other compound fields and uses inflate/deflate co
 
 =head1 AUTHOR
 
-John C. Siracusa (siracusa@mindspring.com)
+John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
