@@ -19,7 +19,7 @@ Rose::HTML::Form::Field::WithContents->import_methods(
   xhtml_tag => '_xhtml_tag',
 });
 
-our $VERSION = '0.549';
+our $VERSION = '0.551';
 
 sub _item_class       { 'Rose::HTML::Form::Field::Option' }
 sub _item_group_class { 'Rose::HTML::Form::Field::OptionGroup' }
@@ -30,6 +30,7 @@ sub _item_name_plural { 'options' }
 *options_localized     = \&Rose::HTML::Form::Field::Group::items_localized;
 *option                = \&Rose::HTML::Form::Field::Group::OnOff::item;
 *option_group          = \&Rose::HTML::Form::Field::Group::OnOff::item_group;
+*visible_options       = \&Rose::HTML::Form::Field::Group::visible_items;
 
 *add_options           = \&Rose::HTML::Form::Field::Group::add_items;
 *add_option            = \&add_options;
@@ -39,12 +40,20 @@ sub _item_name_plural { 'options' }
 *add_options_localized = \&Rose::HTML::Form::Field::Group::add_items_localized;
 *add_option_localized  = \&Rose::HTML::Form::Field::Group::add_item_localized;
 
-
 *choices           = \&options;
 *choices_localized = \&options_localized;
 
 *_args_to_items = \&Rose::HTML::Form::Field::Group::_args_to_items;
 
+*show_all_options = \&Rose::HTML::Form::Field::Group::show_all_items;
+*hide_all_options = \&Rose::HTML::Form::Field::Group::hide_all_items;
+
+*delete_option  = \&Rose::HTML::Form::Field::Group::delete_item;
+*delete_options = \&Rose::HTML::Form::Field::Group::delete_items;
+
+*delete_option_group  = \&Rose::HTML::Form::Field::Group::delete_item_group;
+*delete_option_groups = \&Rose::HTML::Form::Field::Group::delete_item_groups;
+
 sub html_element  { 'select' }
 sub xhtml_element { 'select' }
 
@@ -53,14 +62,14 @@ sub xhtml_element { 'select' }
 sub html_field
 {
   my($self) = shift;
-  $self->contents("\n" . join("\n", map { $_->html_field } $self->options) . "\n");
+  $self->contents("\n" . join("\n", map { $_->html_field } $self->visible_options) . "\n");
   return $self->_html_tag(@_);
 }
 
 sub xhtml_field
 {
   my($self) = shift; 
-  $self->contents("\n" . join("\n", map { $_->xhtml_field } $self->options) . "\n");
+  $self->contents("\n" . join("\n", map { $_->xhtml_field } $self->visible_options) . "\n");
   return $self->_xhtml_tag(@_);
 }
 
@@ -101,5 +110,26 @@ sub hidden_fields
   return (wantarray) ? @hidden : \@hidden;
 }
 
+sub hidden
+{
+  my($self) = shift;
+
+  if(@_)
+  {
+    if($self->{'_hidden'} = shift(@_) ? 1 : 0)
+    {
+      foreach my $option ($self->options)
+      {
+        $option->selected(undef);
+      }
+    }
+  }
+
+  return $self->{'_hidden'};
+}
+
+sub hide { shift->hidden(1) }
+sub show { shift->hidden(0) }
+
 1;
 
