@@ -38,6 +38,25 @@ sub xhtml { shift->xhtml_field(@_) }
 
 sub init_apply_error_class { 0 }
 
+sub hidden
+{
+  my($self) = shift;
+  
+  if(@_)
+  {
+    my $bool = shift;
+
+    $self->SUPER::hidden($bool);
+    
+    foreach my $option ($self->options)
+    {
+      $option->hidden($bool);
+    }
+  }
+  
+  return $self->SUPER::hidden(@_);
+}
+
 1;
 
 __END__
