@@ -5,7 +5,7 @@ use strict;
 use Rose::HTML::Form::Field::OnOff::Checkable;
 our @ISA = qw(Rose::HTML::Form::Field::OnOff::Checkable);
 
-our $VERSION = '0.011';
+our $VERSION = '0.551';
 
 __PACKAGE__->delete_valid_html_attrs(qw(ismap usemap alt src));
 __PACKAGE__->required_html_attr_value(type => 'radio');
@@ -137,6 +137,14 @@ Constructs a new L<Rose::HTML::Form::Field::RadioButton> object based on PARAMS,
 
 Check or uncheck the radio button by passing a boolean value.  If BOOL is true, the radio button will be checked. If it is false, it will be unchecked. Returns true if the radio button is checked, false otherwise.
 
+=item B<hidden [BOOL]>
+
+Get or set a boolean value that indicates whether or not this radio button will be shown in its parent L<radio button group|Rose::HTML::Form::Field::RadioButtonGroup>.  Setting it to true also sets L<checked|/checked> to false.
+
+=item B<hide>
+
+Class L<hidden|/hidden>, passing a true value.
+
 =item B<html_radio_button>
 
 Returns the HTML serialization of the radio button field only (i.e., without any label or error message)
@@ -149,6 +157,10 @@ Returns true if the radio button is checked, false otherwise.
 
 Simply calls L<is_checked()|/is_checked>.  This method exists for API uniformity between radio buttons and checkboxes.
 
+=item B<show>
+
+Class L<hidden|/hidden>, passing a false value.
+
 =item B<value [VALUE]>
 
 Gets or sets the value of the "value" HTML attribute.
