@@ -10,7 +10,7 @@ use Rose::HTML::Form::Field::Group;
 use Rose::HTML::Form::Field::Group::OnOff;
 our @ISA = qw(Rose::HTML::Form::Field::Group::OnOff);
 
-our $VERSION = '0.549';
+our $VERSION = '0.551';
 
 sub _item_class       { 'Rose::HTML::Form::Field::RadioButton' }
 sub _item_name        { 'radio button' }
@@ -19,6 +19,7 @@ sub _item_name_plural { 'radio buttons' }
 *radio_buttons               = \&Rose::HTML::Form::Field::Group::items;
 *radio_buttons_localized     = \&Rose::HTML::Form::Field::Group::items_localized;
 *radio_button                = \&Rose::HTML::Form::Field::Group::OnOff::item;
+*visible_radio_buttons       = \&Rose::HTML::Form::Field::Group::visible_items;
 
 *add_radio_buttons           = \&Rose::HTML::Form::Field::Group::add_items;
 *add_radio_button            = \&add_radio_buttons;
@@ -28,6 +29,15 @@ sub _item_name_plural { 'radio buttons' }
 *choices           = \&radio_buttons;
 *choices_localized = \&radio_buttons_localized;
 
+*show_all_radio_buttons = \&Rose::HTML::Form::Field::Group::show_all_items;
+*hide_all_radio_buttons = \&Rose::HTML::Form::Field::Group::hide_all_items;
+
+*delete_radio_button  = \&Rose::HTML::Form::Field::Group::delete_item;
+*delete_radio_buttons = \&Rose::HTML::Form::Field::Group::delete_items;
+
+*delete_radio_button_group  = \&Rose::HTML::Form::Field::Group::delete_item_group;
+*delete_radio_button_groups = \&Rose::HTML::Form::Field::Group::delete_item_groups;
+
 sub internal_value
 {
   my($self) = shift;
@@ -64,7 +74,7 @@ sub html_table
   if($args{'_xhtml'})
   {
     return
-      $self->SUPER::html_table(items       => scalar $self->radio_buttons,
+      $self->SUPER::html_table(items       => scalar $self->visible_radio_buttons,
                                format_item => \&Rose::HTML::Form::Field::Group::_xhtml_item,
                                %args);
   }
@@ -217,10 +227,22 @@ This is an alias for the L<radio_buttons|/radio_buttons> method.
 
 Get or set the default number of columns to use in the output of the L<html_table()|/html_table> and L<xhtml_table()|/xhtml_table> methods.
 
+=item B<delete_radio_button VALUE>
+
+Deletes the first radio button (according to the order that they are returned from L<radio_buttons()|/radio_buttons>) whose "value" HTML attribute is VALUE.  Returns the deleted radio button or undef if no such radio button exists.
+
+=item B<delete_radio_buttons LIST>
+
+Repeatedly calls L<delete_radio_button|/delete_radio_button>, passing each value in LIST.
+
 =item B<has_value VALUE>
 
 Returns true if the radio button whose value is VALUE is selected, false otherwise.
 
+=item B<hide_all_radio_buttons>
+
+Set L<hidden|Rose::HTML::Form::Field::RadioButton/hidden> to true for all L<radio_buttons|/radio_buttons>.
+
 =item B<html>
 
 Returns the HTML for radio button group, which consists of the L<html()|/html> for each radio button object joined by L<html_linebreak()|/html_linebreak> if L<linebreak()|/linebreak> is true, or single spaces if it is false.
@@ -299,12 +321,16 @@ To set an ordered list of radio buttons along with labels in the constructor, us
 
 Remember that methods are called in the order that they appear in the constructor arguments (see the L<Rose::Object> documentation), so L<radio_buttons()|/radio_buttons> will be called before L<labels()|/labels> in the example above. This is important; it will not work in the opposite order.
 
-Returns a list of the radio button group's L<Rose::HTML::Form::Field::RadioButton> objects in list context, or a reference to an array of the same in scalar context. These are the actual objects used in the field. Modifying them will modify the field itself.
+Returns a list of the radio button group's L<Rose::HTML::Form::Field::RadioButton> objects in list context, or a reference to an array of the same in scalar context.  L<Hidden|Rose::HTML::Form::Field::RadioButton/hidden> radio buttons I<will> be included in this list.  These are the actual objects used in the field. Modifying them will modify the field itself.
 
 =item B<rows [ROWS]>
 
 Get or set the default number of rows to use in the output of the L<html_table()|/html_table> and L<xhtml_table()|/xhtml_table> methods.
 
+=item B<show_all_radio_buttons>
+
+Set L<hidden|Rose::HTML::Form::Field::RadioButton/hidden> to false for all L<radio_buttons|/radio_buttons>.
+
 =item B<value [VALUE]>
 
 Simply calls L<input_value()|Rose::HTML::Form::Field/input_value>, passing all arguments.
